@@ -58,7 +58,7 @@ class PsmPy:
         self.controln = len(self.controldf)
 
     def logistic_ps(self, balance=True):
-        """
+        """ 
         Fits logistic regression model(s) used for generating propensity scores
         Parameters
         ----------
@@ -489,7 +489,7 @@ class PsmPy:
         save   : Bool
             Whether to save the figure in pwd (default = False)
         Returns
-        plot_match : fig
+        grpahic
         """
         dftreat = self.df_matched[self.df_matched[self.treatment] == 1]
         dfcontrol = self.df_matched[self.df_matched[self.treatment] == 0]
@@ -527,7 +527,7 @@ class PsmPy:
         save : bool
             Save graphic or not (default = False)
         Returns
-        Seaborn graphic
+        seaborn graphic
         """
         df_preds_after = self.df_matched[[self.treatment] + self.xvars]
         df_preds_b4 = self.data[[self.treatment] + self.xvars]
@@ -536,16 +536,10 @@ class PsmPy:
 
         data = []
         for cl in self.xvars:
-            try:
-                data.append([cl, 'before', cohenD(
-                    df_preds_b4_float, self.treatment, cl)])
-            except:
-                data.append([cl, 'before', 0])
-            try:
-                data.append([cl, 'after', cohenD(
-                    df_preds_after_float, self.treatment, cl)])
-            except:
-                data.append([cl, 'after', 0])
+            data.append([cl, 'before', cohenD(
+                df_preds_b4_float, self.treatment, cl)])
+            data.append([cl, 'after', cohenD(
+                df_preds_after_float, self.treatment, cl)])
         self.effect_size = pd.DataFrame(
             data, columns=['Variable', 'matching', 'Effect Size'])
         sns.set_style("white")
